package com.sensu.automall.activity_search

import android.content.Intent
import android.os.Bundle
import android.support.v7.widget.LinearLayoutManager
import android.support.v7.widget.RecyclerView
import android.text.TextUtils
import android.view.KeyEvent
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import com.annotation.IRouter
import com.qipeilong.base.commonadapter.rv.MultiItemTypeAdapter
import com.qpl.loadstate.LoadState
import com.qpl.loadstate.LoadViewState
import com.qpl.loadstate.NoDataLoadState
import com.qpl.loadstate.NoNetWorkLoadViewState
import com.sensu.automall.BaseActivity
import com.sensu.automall.BaseFragment
import com.sensu.automall.R
import com.sensu.automall.URL
import com.sensu.automall.activity_main.MainActivity
import com.sensu.automall.adapter.SearchSortLeftAdapter
import com.sensu.automall.db.SearchSortDBUtils
import com.sensu.automall.fragment.SearchSortFragment
import com.sensu.automall.manager.SetStatusStrategry
import com.sensu.automall.manager.StatusStrategry
import com.sensu.automall.model.SearchSortItem
import com.sensu.automall.model.SearchSortModel
import com.sensu.automall.recyclerview.SearchSortHeadDecoration
import com.sensu.automall.recyclerview.TobeQuotePriceItemDecoration
import com.sensu.automall.utils.*
import io.reactivex.Observable
import kotlinx.android.synthetic.main.activity_search2.*
import org.json.JSONException
import org.json.JSONObject
import java.lang.Exception

//@IRouter(path = "/SearchActivity",desc = "分类")
class SearchFragment:BaseFragment() {

    lateinit var categoryAdapter: SearchSortLeftAdapter
    lateinit var searchSortFragment:SearchSortFragment
    val categoryList= arrayListOf<SearchSortModel>()
    val rightSorts = arrayListOf<SearchSortItem>()
    var isMoved=false
    var mLocalData =false
    var mLocalGsonStr =""

    lateinit var rootView:View

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
    }

    override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?, savedInstanceState: Bundle?): View? {
        rootView = inflater.inflate(R.layout.fragment_search, container, false)
        return rootView
    }

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        initView()
    }

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)
        mLoadState = LoadState.newInstance().register(lay_content, object :  LoadViewState.OnReloadListener{
            override fun reload() {
                if (MassageUtils.isNetworkConnected(context)) {
                    mLoadState.hideLoadViewState(NoNetWorkLoadViewState::class.java)
                }
                if(!mLocalData && MassageUtils.isNetworkConnected(context)){
                    GetViewCatalogPages()
                }
            }

        })
        loadData()
    }

     fun initView() {
        categoryAdapter=SearchSortLeftAdapter(context!!,R.layout.item_searchsort_left,categoryList)
        rv_sort.adapter=categoryAdapter
        rv_sort.addItemDecoration(TobeQuotePriceItemDecoration(context,TobeQuotePriceItemDecoration.VERTICAL_LIST,MassageUtils.dip2px(2f),R.color.bg_content))
        rv_sort.layoutManager=LinearLayoutManager(context)

        categoryAdapter.setOnItemClickListener(object:MultiItemTypeAdapter.OnItemClickListener{
            override fun onItemLongClick(view: View?, holder: RecyclerView.ViewHolder?, position: Int): Boolean {
                return false
            }

            override fun onItemClick(view: View?, holder: RecyclerView.ViewHolder?, position: Int) {
                if(searchSortFragment!=null){
                    isMoved=true
                    setChecked(position,true)
                }
            }
        })
        createFragment()
    }

    override fun loadData() {
        super.loadData()
        getDataFromDB()
    }

    fun getDataFromDB(){
        Observable.create<List<SearchSortModel>>{
            it.onNext(SearchSortDBUtils.instance.findAllFromSP(context!!))
        }.compose(RxjavaUtils.observableToMain()).subscribe({
            mLocalData =if(it?.size == 0)false else true
            categoryList.clear()
            categoryList.addAll(it)
            handleData()
            mLocalGsonStr =MassageUtils.getFromSP(context!!,
                    SharedPreferenceUtil.SEARCHSORT_TITLE,SharedPreferenceUtil.SEARCHSORT_KEY)
            GetViewCatalogPages()
        },{
            if (!MassageUtils.isNetworkConnected(context)) {
                mLoadState.showLoadViewState(NoNetWorkLoadViewState::class.java)
            }else{
                GetViewCatalogPages()
            }
        })
    }

    fun handleData(){
        rightSorts.clear()
        categoryList?.forEachIndexed { index, searchSortModel ->
            var nextParentTitle=""
            if(index < categoryList.size-1){
                nextParentTitle = categoryList.get(index+1).Title
            }
            val banner = SearchSortItem("",searchSortModel.Title,"",-1,-1,"",
                    true,false,false,false,searchSortModel.BannerItems,index.toString(),searchSortModel.Title,nextParentTitle)
            rightSorts.add(banner)

            searchSortModel.NavigationItems?.forEach {
                it.bannerType =false
                it.nav =true
                it.tag = index.toString()
                it.parentTitle =searchSortModel.Title
                it.nextParentTitle =nextParentTitle
                it.empty =false
                rightSorts.add(it)
            }

            var navigations = searchSortModel.NavigationItems?.size % SearchSortFragment.SPAN_COUNT

            var need_add_empty = SearchSortFragment.SPAN_COUNT - navigations
            if(navigations == 0)  need_add_empty=0

            var need_add_lastRow =navigations
            if(need_add_lastRow == 0){
                need_add_lastRow = SearchSortFragment.SPAN_COUNT
            }
            if(searchSortModel.NavigationItems?.size>0){
                for (i in 0 until need_add_lastRow){
                    searchSortModel.NavigationItems?.get(searchSortModel.NavigationItems?.size - i-1).lastrow =true
                }
            }
            for (i in 0 until need_add_empty){
                rightSorts.add(SearchSortItem("","","",-1,-1,"",
                        false,true,true,true, mutableListOf(),index.toString(),"",""))
            }

            searchSortModel.CatalogItems?.forEachIndexed { cata_index, searchSortItem ->
                searchSortItem.bannerType =false
                searchSortItem.nav =false
                searchSortItem.empty =false
                searchSortItem.tag = index.toString()
                searchSortItem.parentTitle =searchSortModel.Title
                searchSortItem.nextParentTitle =nextParentTitle
                rightSorts.add(searchSortItem)
            }
        }
        categoryAdapter.notifyDataSetChanged()

        if(searchSortFragment!=null ){
            searchSortFragment.setSorts(rightSorts)
        }
    }

//    override fun reload() {
//        super.reload()
//        if (MassageUtils.isNetworkConnected(context)) {
//            mLoadState.hideLoadViewState(NoNetWorkLoadViewState::class.java)
//        }
//        if(!mLocalData && MassageUtils.isNetworkConnected(context)){
//            GetViewCatalogPages()
//        }
//    }

    fun GetViewCatalogPages(){
        if(!mLocalData){
//            LoadingDialog.getInstance().ShowLoading(context,lay_content,false)
            request(RequestParams(), "GetViewCatalogPages",URL.HTTP_GetViewCatalogPages,true)
        }else{
            request(RequestParams(), "GetViewCatalogPages",URL.HTTP_GetViewCatalogPages,false)
        }

//        client.postRequest("GetViewCatalogPages",URL.HTTP_GetViewCatalogPages,params,activityKey)
    }

    private fun setChecked( position:Int,isLeft:Boolean){
        if(isLeft){
            categoryAdapter.checkItemClick(position)
            var count =0
            for ( i in 0 until position){
                count +=(categoryList.get(i).CatalogItems?.size + categoryList.get(i).NavigationItems?.size)
                var navigations = categoryList[i].NavigationItems?.size % SearchSortFragment.SPAN_COUNT
                if(navigations > 0){
                    count +=(SearchSortFragment.SPAN_COUNT - navigations)
                }
            }

            count+=position
            searchSortFragment.leftClick(count)


        }else{
            if(isMoved){
                isMoved=false
            }else{
                categoryAdapter.checkItemClick(position)
            }
            SearchSortHeadDecoration.mCurrentTag=position.toString()
        }
        moveToCenter(position)
    }

    private fun moveToCenter(position: Int){
        var childAt = rv_sort.getChildAt(position - (rv_sort.layoutManager as LinearLayoutManager).findFirstVisibleItemPosition())
        childAt?.let {
            var y = it.top - rv_sort.height/2
            rv_sort.smoothScrollBy(0,y)
        }
    }

    private fun createFragment(){
        var fragmentTransaction =requireFragmentManager().beginTransaction()
        searchSortFragment= SearchSortFragment()
        var bundle =Bundle()
        bundle.putSerializable("category",rightSorts)
        searchSortFragment.arguments=bundle
        searchSortFragment.setCheckListener(object :SearchSortHeadDecoration.CheckListener{
            override fun check(position: Int, isScroll: Boolean) {
                setChecked(position,isScroll)
            }
        })
        if (requireFragmentManager().findFragmentByTag("searchsort")!=null){
            fragmentTransaction.show(requireFragmentManager().findFragmentByTag("searchsort")).commit()
        }else{
            fragmentTransaction.add(R.id.lin_fragment,searchSortFragment,"searchsort")
            fragmentTransaction.commit()
        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if(requestCode == 1000){
            if (data != null) {
                val text = data.getStringExtra("text")
                val mode_stwitch = MassageUtils.getModeStwitch(context);
                if (TextUtils.isEmpty(mode_stwitch) || mode_stwitch == SharedPreferenceUtil.MODE_SWITCH_AutoMallProductList) {
                    val intent = Intent(context, AutoMallProductListActivity::class.java)
                    intent.putExtra("keyword",text)
                    startActivity(intent)
                } else if (mode_stwitch == SharedPreferenceUtil.MODE_SWITCH_OldProductList) {
//                    OldProductListActivity.startActivity(context, "", "", "", "", text)
                    ProductListActivity.startActivity(context!!, "", "", "", "", text)
                }
            }
        }
    }

    override fun onSuccess(json: String?) {
        super.onSuccess(json)
        val `object` = JSONObject(json)
        val body = JSONObject(`object`.optString("body"))
        val method = `object`.optString("method")
        try {
            if("GetViewCatalogPages".equals(method)){
                var data = body?.optJSONArray("Data").toString()
                val searchsorts = GsonParseUtil.parseArray(data,SearchSortModel::class.java)

                if(searchsorts==null || searchsorts.size ==0){
                    if(!mLocalData){
                        mLoadState.showLoadViewState(NoDataLoadState::class.java)
                    }else{
                        //categoryList.clear()
                        handleData()
                        MassageUtils.deleteToSP(context,SharedPreferenceUtil.SEARCHSORT_TITLE)
                    }
                }else{
                    mLoadState.hideLoadViewState(NoDataLoadState::class.java)

                    if(mLocalGsonStr?.hashCode() === data?.hashCode()){
                    }else{
                        categoryList.clear()
                        categoryList.addAll(searchsorts)
                        handleData()
                        MassageUtils.saveToSP(context,SharedPreferenceUtil.SEARCHSORT_TITLE,SharedPreferenceUtil.SEARCHSORT_KEY,data)
                    }
                }
            }
        }catch (e:Exception){
            e.printStackTrace()
        }
    }

    override fun onFail(json: String?) {
        super.onFail(json)
    }

}


