package com.sensu.automall.adapter

import android.content.Context
import android.support.v7.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.TextView

import com.sensu.automall.R
import com.sensu.automall.model.TypeItem

class ToQuoteAdapter : RecyclerView.Adapter<ToQuoteAdapter.ViewHolder> {

    private lateinit var context: Context
    private var data: List<TypeItem>? = null
    var clickListener: MyItemClickListener? = null

    constructor(context: Context, data: List<TypeItem>, clickListener: MyItemClickListener?) {
        this.context = context
        this.data = data
        this.clickListener = clickListener
    }

    constructor(context: Context, data: List<TypeItem>) {
        ToQuoteAdapter(context, data, null)
    }

    fun setData(data: List<TypeItem>) {
        this.data = data
        notifyDataSetChanged()
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        val view = LayoutInflater.from(context).inflate(R.layout.item_to_quote, parent, false)
        return ViewHolder(view, clickListener)
    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val item = data!![position]
        if (item.isShowCatalog) {
            holder.tvCatalog.visibility = View.VISIBLE
            holder.tvCatalog.text = item.catalog
        } else {
            holder.tvCatalog.visibility = View.GONE
        }
        holder.tvTitle.text = item.title
    }

    override fun getItemCount(): Int {
        return if (data == null) 0 else data!!.size
    }

    class ViewHolder(itemView: View, internal var myItemClickListener: MyItemClickListener?) : RecyclerView.ViewHolder(itemView), View.OnClickListener {

        internal var tvCatalog: TextView
        internal var tvTitle: TextView

        init {
            tvCatalog = itemView.findViewById(R.id.catalog)
            tvTitle = itemView.findViewById(R.id.title)
            tvTitle.setOnClickListener(this)
        }

        override fun onClick(v: View) {
            if (null != myItemClickListener) {
                myItemClickListener!!.onItemClick(v, adapterPosition)
            }
        }
    }

    interface MyItemClickListener {
        fun onItemClick(view: View, pos: Int)
    }

}
