package com.sensu.automall.view

import android.content.Context
import android.graphics.drawable.ColorDrawable
import android.text.TextUtils
import android.view.LayoutInflater
import android.view.View
import android.view.View.OnTouchListener
import android.view.ViewGroup
import android.widget.LinearLayout
import android.widget.PopupWindow
import android.widget.TextView
import com.sensu.automall.R
import com.sensu.automall.model.PickAspectRatioBean
import com.sensu.automall.model.PickTireSize
import java.util.*

class ChooseTireScalePopup(context: Context, listener:OnDismissListener) : PopupWindow(context) {
    val context: Context
    var btn_sure: TextView
    var btn_reset: TextView
    private val mLayoutWheel: LinearLayout //选择器容器
    private val mWheelViewTireWidth: TireScaleWheelView
    private val mWheelViewRatio: TireScaleWheelView
    private val mWheelViewDiameter: TireScaleWheelView

    private var dataGroup: List<PickTireSize>? = null //总的联动列表
    private var mTireWidthList : List<String> = ArrayList() //轮胎宽度列表
    private var mRatioList: List<String> = ArrayList() //当前扁平比列表
    private var mRimList: List<String> = ArrayList() //当前直径列表

    fun setList(dataList: List<PickTireSize>,tireWidth:String, ratio:String, diameter:String) {
        /**  dataGroup 和 mTireWidthList 长度，顺序一致，便于 WheelView 直接根据选中位置联动
         * 子列表 和 子列表的字符串列表 也必须 长度、顺序一致 ，原因同上 */
        dataGroup = ArrayList<PickTireSize>()
        mTireWidthList = ArrayList<String>()
        for (i in dataList.indices) {
            val width: String = dataList[i].width
            if (!TextUtils.isEmpty(width) && !TextUtils.isEmpty(width.trim { it <= ' ' }) && !(mTireWidthList as ArrayList<String>).contains(
                            width.trim { it <= ' ' })) {
                (dataGroup as ArrayList<PickTireSize>).add(dataList.get(i))
                (mTireWidthList as ArrayList<String>).add(width)
            }
        }
        if ((mTireWidthList as ArrayList<String>).isEmpty()) {
            return
        }
        mLayoutWheel.visibility = View.VISIBLE
        initWheelViewData()
        initDefaultTireSize(tireWidth,ratio,diameter)
    }
    private fun initDefaultTireSize(tireWidth:String, ratio:String, diameter:String) {

        if (mTireWidthList.isNotEmpty()) {
            val widthPosition:Int = if (TextUtils.isEmpty(tireWidth)){
                mTireWidthList.indexOf("205")
            }else{
                mTireWidthList.indexOf(tireWidth)
            }
            mWheelViewTireWidth.currentItem = widthPosition
        }
        if ( mRatioList.isNotEmpty()) {
            val ratioPosition:Int = if(TextUtils.isEmpty(ratio)){
                mRatioList.indexOf("55")
            }else{
                mRatioList.indexOf(ratio)
            }
            mWheelViewRatio.currentItem = ratioPosition
        }
        if (mRimList.isNotEmpty()) {
            val rimPosition:Int = if(TextUtils.isEmpty(diameter)){
                mRimList.indexOf("16")
            }else{
                mRimList.indexOf(diameter)
            }
            mWheelViewDiameter.currentItem = rimPosition
        }
    }

    /**
     * 初始化 WheelVie 数据
     * 初始化的值为 205/55R16
     */
    private fun initWheelViewData() {
        /**  初始化WheelView显示  */ //获得当前值
        val mTireWidthArray = mTireWidthList.toTypedArray()
        mWheelViewTireWidth.adapter = ArrayItemTypeAdapter(mTireWidthArray)
        mWheelViewTireWidth.currentItem = 0
        //设置默认显示的 第一条 数据
        initTireWidthChosen()
        /**  WheelView 滑动事件  */
        mWheelViewTireWidth.addChangingListener(object : OnWheelChangedListener{
            override fun onChanged(wheel: TireScaleWheelView, oldValue: Int, newValue: Int) {
//                if (wheel.valuePaint != null) {
//                    wheel.valuePaint.textSize = context.resources.getDimension(R.dimen.text_size_large_big)
//                }
                initTireWidthChosen()
            }
        })
        mWheelViewRatio.addChangingListener(object : OnWheelChangedListener {
            override fun onChanged(wheel: TireScaleWheelView, oldValue: Int, newValue: Int) {
//                if (wheel.valuePaint != null) {
//                    wheel.valuePaint.textSize = context.resources.getDimension(R.dimen.text_size_large_big)
//                }
                initRatioChosen()
            }
        })
        mWheelViewDiameter.addChangingListener(object : OnWheelChangedListener {
            override fun onChanged(wheel: TireScaleWheelView, oldValue: Int, newValue: Int) {
//                if (wheel.valuePaint != null) {
//                    wheel.valuePaint.textSize = context.resources.getDimension(R.dimen.text_size_large_big)
//                }
            }
        })
    }

    /**
     * 选中轮胎宽度
     */
    private fun initTireWidthChosen() { //当胎面宽被选中时,得到 扁平比数据 mRatioList
        val currentTireWidthItem = mWheelViewTireWidth.currentItem
        mRatioList = dataGroup!![currentTireWidthItem].aspectRatioStringList
        val mRatioArray = mRatioList.toTypedArray()
        mWheelViewRatio.adapter = ArrayItemTypeAdapter(mRatioArray)
        mWheelViewRatio.currentItem = 0
        //当扁平比被选中时,得到 直径集合 mRimList
        val currentRatioList: List<PickAspectRatioBean>? = dataGroup!![currentTireWidthItem].aspectRatioList
        mRimList = if (currentRatioList == null || currentRatioList.isEmpty()) {
            ArrayList()
        } else {
            currentRatioList[0].rimStringList
        }
        val mDiameterArray = mRimList.toTypedArray()
        mWheelViewDiameter.adapter = ArrayItemTypeAdapter(mDiameterArray)
        mWheelViewDiameter.currentItem = 0
    }

    /**
     * 扁平比选中
     */
    private fun initRatioChosen() {
        val currentTireItem = mWheelViewTireWidth.currentItem
        val currentRatioItem = mWheelViewRatio.currentItem
        mRimList = dataGroup!![currentTireItem]
                .aspectRatioList[currentRatioItem]
                .rimStringList
        val mRimArray = mRimList.toTypedArray()
        mWheelViewDiameter.adapter = ArrayItemTypeAdapter(mRimArray)
        mWheelViewDiameter.currentItem = 0
    }

    override fun dismiss() {
        super.dismiss()
    }


    interface OnSureClicklistener {
        fun onSure(tireWidth:String, ratio:String, diameter:String)
    }

    private var onSureClicklistener: OnSureClicklistener? = null

    fun setOnSureClicklistener(listener: OnSureClicklistener?) {
        onSureClicklistener = listener
    }

    /**
     * 设置WheelView的样式
     */
    private fun setWheelViewStyle(wheelView: TireScaleWheelView?) {
        if (wheelView == null) {
            return
        }
        // 高亮的颜色
        wheelView.setTextPaintColor("#333333")
        // 上下字体颜色
        wheelView.setDrawItemsText("#999999")
        // 线条颜色
        wheelView.setDrawToPectPain("#999999")
        //解决触摸事件冲突 父控件不处理
        wheelView.setOnTouchListener(OnTouchListener { v, arg1 ->
            v.parent.requestDisallowInterceptTouchEvent(true)
            false
        })
        //可循环滚动
/*wheelView.setCyclic(true);*/
    }

    init {
        this.context = context
        val mContentView = LayoutInflater.from(context).inflate(R.layout.popup_tire_scale, null)
        mLayoutWheel = mContentView.findViewById(R.id.layout_wheel)
        mWheelViewTireWidth = mContentView.findViewById(R.id.whlee_edtmk)
        mWheelViewRatio = mContentView.findViewById(R.id.whlee_edbpb)
        mWheelViewDiameter = mContentView.findViewById(R.id.whlee_zj)
        setWheelViewStyle(mWheelViewTireWidth)
        setWheelViewStyle(mWheelViewRatio)
        setWheelViewStyle(mWheelViewDiameter)
        btn_sure = mContentView.findViewById<View>(R.id.btn_sure) as TextView
        btn_reset =  mContentView.findViewById<View>(R.id.btn_reset) as TextView
        btn_reset.setOnClickListener{
            if (onSureClicklistener != null) {
                onSureClicklistener!!.onSure("","","")
            }
            dismiss()
        }
        btn_sure.setOnClickListener {
            val tireWidthItem = mWheelViewTireWidth.currentItem
            var tireWidth = ""
            if ( tireWidthItem >= 0 && tireWidthItem < mTireWidthList.size) {
                tireWidth = mTireWidthList[tireWidthItem]
            }

            val ratioItem = mWheelViewRatio.currentItem
            var ratio = ""
            if (ratioItem >= 0 && ratioItem < mRatioList.size) {
                ratio = mRatioList[ratioItem]
            }

            val diameterItem = mWheelViewDiameter.currentItem
            var diameter = ""
            if (diameterItem >= 0 && diameterItem < mRimList.size) {
                diameter = mRimList[diameterItem]
            }
            if (onSureClicklistener != null) {
                onSureClicklistener!!.onSure(tireWidth,ratio,diameter)
            }
            dismiss()
        }

        contentView = mContentView
        //设置SelectPicPopupWindow弹出窗体的宽
        this.width = ViewGroup.LayoutParams.MATCH_PARENT
        //设置SelectPicPopupWindow弹出窗体的高
        this.height = ViewGroup.LayoutParams.MATCH_PARENT
        this.isFocusable = true
        this.isTouchable = true
        this.isOutsideTouchable = false
        this.setOnDismissListener (listener)
        setBackgroundDrawable(ColorDrawable(0x00000000))
//        initWheelViewData()
    }
}